@@ -221,7 +221,7 @@ abstract class Presenter extends Control implements Application\IPresenter
 			// continue with shutting down
 			if ($this->isAjax()) try {
 				$hasPayload = (array) $this->payload; unset($hasPayload['state']);
-				if ($this->response instanceof Responses\TextResponse && $this->isControlInvalid()) { // snippets - TODO
+				if ($this->response instanceof Responses\TextResponse && $this->isControlInvalid()) {
 					$this->snippetMode = TRUE;
 					$this->response->send($this->httpRequest, $this->httpResponse);
 					$this->sendPayload();
@@ -287,7 +287,7 @@ abstract class Presenter extends Control implements Application\IPresenter
 	public function checkRequirements($element)
 	{
 		$user = (array) $element->getAnnotation('User');
-		if (in_array('loggedIn', $user) && !$this->user->isLoggedIn()) {
+		if (in_array('loggedIn', $user, TRUE) && !$this->user->isLoggedIn()) {
 			throw new Application\ForbiddenRequestException;
 		}
 	}
@@ -469,6 +469,7 @@ abstract class Presenter extends Control implements Application\IPresenter
 	/**
 	 * Finds layout template file name.
 	 * @return string
+	 * @internal
 	 */
 	public function findLayoutTemplateFile()
 	{
@@ -691,6 +692,7 @@ abstract class Presenter extends Control implements Application\IPresenter
 	/**
 	 * Link to myself.
 	 * @return string
+	 * @deprecated
 	 */
 	public function backlink()
 	{
@@ -701,6 +703,7 @@ abstract class Presenter extends Control implements Application\IPresenter
 	/**
 	 * Returns the last created Request.
 	 * @return Nette\Application\Request
+	 * @internal
 	 */
 	public function getLastCreatedRequest()
 	{
@@ -712,6 +715,7 @@ abstract class Presenter extends Control implements Application\IPresenter
 	 * Returns the last created Request flag.
 	 * @param  string
 	 * @return bool
+	 * @internal
 	 */
 	public function getLastCreatedRequestFlag($flag)
 	{
@@ -867,7 +871,7 @@ abstract class Presenter extends Control implements Application\IPresenter
 					throw new InvalidLinkException("Unable to pass parameters to 'this!' signal.");
 				}
 
-			} elseif (strpos($signal, self::NAME_SEPARATOR) === FALSE) { // TODO: AppForm exception
+			} elseif (strpos($signal, self::NAME_SEPARATOR) === FALSE) {
 				// counterpart of signalReceived() & tryCall()
 				$method = $component->formatSignalMethod($signal);
 				if (!$reflection->hasCallableMethod($method)) {
@@ -898,7 +902,7 @@ abstract class Presenter extends Control implements Application\IPresenter
 				$action = self::DEFAULT_ACTION;
 			}
 
-			$current = ($action === '*' || strcasecmp($action, $this->action) === 0) && $presenterClass === get_class($this); // TODO
+			$current = ($action === '*' || strcasecmp($action, $this->action) === 0) && $presenterClass === get_class($this);
 
 			$reflection = new PresenterComponentReflection($presenterClass);
 			if ($args || $destination === 'this') {
@@ -1255,6 +1259,7 @@ abstract class Presenter extends Control implements Application\IPresenter
 	 * Pops parameters for specified component.
 	 * @param  string  component id
 	 * @return array
+	 * @internal
 	 */
 	public function popGlobalParameters($id)
 	{
