@@ -93,6 +93,7 @@ class Compiler extends Nette\Object
 	}
 
 
+	/** @internal */
 	public function processParameters()
 	{
 		if (isset($this->config['parameters'])) {
@@ -101,6 +102,7 @@ class Compiler extends Nette\Object
 	}
 
 
+	/** @internal */
 	public function processExtensions()
 	{
 		for ($i = 0; $slice = array_slice($this->extensions, $i, 1, TRUE); $i++) {
@@ -118,6 +120,7 @@ class Compiler extends Nette\Object
 	}
 
 
+	/** @internal */
 	public function processServices()
 	{
 		$this->parseServices($this->builder, $this->config);
@@ -130,6 +133,7 @@ class Compiler extends Nette\Object
 	}
 
 
+	/** @internal */
 	public function generateCode($className, $parentName)
 	{
 		foreach ($this->extensions as $extension) {
@@ -169,7 +173,7 @@ class Compiler extends Nette\Object
 			$path = array();
 			while (Config\Helpers::isInheriting($def)) {
 				$path[] = $def;
-				$def = $all[$def[Config\Helpers::EXTENDS_KEY]];
+				$def = isset($all[$def[Config\Helpers::EXTENDS_KEY]]) ? $all[$def[Config\Helpers::EXTENDS_KEY]] : array();
 				if (in_array($def, $path, TRUE)) {
 					throw new ServiceCreationException("Circular reference detected for service '$name'.");
 				}
