@@ -179,6 +179,7 @@ class ContainerBuilder extends Nette\Object
 	/**
 	 * Generates $dependencies, $classes and normalizes class names.
 	 * @return array
+	 * @internal
 	 */
 	public function prepareClassList()
 	{
@@ -191,7 +192,7 @@ class ContainerBuilder extends Nette\Object
 			}
 
 			if (!interface_exists($def->implement)) {
-				throw new ServiceCreationException("Interface $def->implement used in service '$name' has not been found.");
+				throw new ServiceCreationException("Interface $def->implement used in service '$name' not found.");
 			}
 			$rc = Reflection\ClassType::from($def->implement);
 			$method = $rc->hasMethod('create') ? $rc->getMethod('create') : ($rc->hasMethod('get') ? $rc->getMethod('get') : NULL);
@@ -204,7 +205,7 @@ class ContainerBuilder extends Nette\Object
 			if (!$def->class && empty($def->factory->entity)) {
 				$returnType = $method->getAnnotation('return');
 				if (!$returnType) {
-					throw new ServiceCreationException("Method $method used in service '$name' has not @return annotation.");
+					throw new ServiceCreationException("Method $method used in service '$name' has no @return annotation.");
 				}
 
 				$returnType = Reflection\AnnotationsParser::expandClassName(preg_replace('#[|\s].*#', '', $returnType), $rc);
@@ -257,7 +258,7 @@ class ContainerBuilder extends Nette\Object
 
 			if (is_string($factory) && preg_match('#^[\w\\\\]+\z#', $factory) && $factory !== self::THIS_SERVICE) {
 				if (!class_exists($factory) || !Reflection\ClassType::from($factory)->isInstantiable()) {
-					throw new ServiceCreationException("Class $factory used in service '$name' has not been found or is not instantiable.");
+					throw new ServiceCreationException("Class $factory used in service '$name' not found or is not instantiable.");
 				}
 			}
 		}
@@ -269,7 +270,7 @@ class ContainerBuilder extends Nette\Object
 			if (!$def->class) {
 				continue;
 			} elseif (!class_exists($def->class) && !interface_exists($def->class)) {
-				throw new ServiceCreationException("Class or interface $def->class used in service '$name' has not been found.");
+				throw new ServiceCreationException("Class or interface $def->class used in service '$name' not found.");
 			} else {
 				$def->class = Reflection\ClassType::from($def->class)->getName();
 			}
@@ -322,8 +323,9 @@ class ContainerBuilder extends Nette\Object
 			try {
 				$reflection = Nette\Utils\Callback::toReflection($factory);
 			} catch (\ReflectionException $e) {
-				$name = array_slice(array_keys($recursive), -1);
-				throw new ServiceCreationException("Factory '" . Nette\Utils\Callback::toString($factory) . "' used in service '$name[0]' is not callable.");
+			}
+			if (isset($e) || !is_callable($factory)) {
+				throw new ServiceCreationException(sprintf("Factory '%s' used in service '%s' is not callable.", Nette\Utils\Callback::toString($factory), $name));
 			}
 			$def->class = preg_replace('#[|\s].*#', '', $reflection->getAnnotation('return'));
 			if ($def->class && $reflection instanceof \ReflectionMethod) {
@@ -454,7 +456,7 @@ class ContainerBuilder extends Nette\Object
 		$setups = (array) $def->setup;
 		if ($def->inject && $def->class) {
 			$injects = array();
-			foreach (Helpers::getInjectProperties(Reflection\ClassType::from($def->class)) as $property => $type) {
+			foreach (Helpers::getInjectProperties(Reflection\ClassType::from($def->class), $this) as $property => $type) {
 				$injects[] = new Statement('$' . $property, array('@\\' . ltrim($type, '\\')));
 			}
 
@@ -599,6 +601,7 @@ class ContainerBuilder extends Nette\Object
 	/**
 	 * Formats PHP statement.
 	 * @return string
+	 * @internal
 	 */
 	public function formatPhp($statement, $args)
 	{
@@ -681,6 +684,7 @@ class ContainerBuilder extends Nette\Object
 	/**
 	 * Converts @service or @\Class -> service name and checks its existence.
 	 * @return string  of FALSE, if argument is not service name
+	 * @internal
 	 */
 	public function getServiceName($arg)
 	{
