@@ -17,14 +17,6 @@ use Nette;
  */
 class MsSqlDriver extends Nette\Object implements Nette\Database\ISupplementalDriver
 {
-	/** @var Nette\Database\Connection */
-	private $connection;
-
-
-	public function __construct(Nette\Database\Connection $connection, array $options)
-	{
-		$this->connection = $connection;
-	}
 
 
 	/********************* SQL ****************d*g**/
