@@ -65,16 +65,18 @@ class SelectBox extends ChoiceControl
 	public function setItems(array $items, $useKeys = TRUE)
 	{
 		if (!$useKeys) {
+			$res = array();
 			foreach ($items as $key => $value) {
 				unset($items[$key]);
 				if (is_array($value)) {
 					foreach ($value as $val) {
-						$items[$key][(string) $val] = $val;
+						$res[$key][(string) $val] = $val;
 					}
 				} else {
-					$items[(string) $value] = $value;
+					$res[(string) $value] = $value;
 				}
 			}
+			$items = $res;
 		}
 		$this->options = $items;
 		return parent::setItems(Nette\Utils\Arrays::flatten($items, TRUE));
@@ -109,7 +111,7 @@ class SelectBox extends ChoiceControl
 	public function validate()
 	{
 		parent::validate();
-		if (!$this->isDisabled() && $this->prompt === FALSE && $this->getValue() === NULL) {
+		if (!$this->isDisabled() && $this->prompt === FALSE && $this->getValue() === NULL && $this->options) {
 			$this->addError(Nette\Forms\Rules::$defaultMessages[self::VALID]);
 		}
 	}
