@@ -315,7 +315,7 @@ class RobotLoader extends Nette\Object
 					case T_CLASS:
 					case T_INTERFACE:
 					case $T_TRAIT:
-						if ($level === $minLevel) {
+						if ($name && $level === $minLevel) {
 							$classes[] = $namespace . $name;
 						}
 						break;
