@@ -167,7 +167,7 @@ class Neon extends Nette\Object
 	private function parse($indent = NULL, $result = NULL)
 	{
 		$inlineParser = $indent === NULL;
-		$value = $key = $object = NULL;
+		$value = $key = NULL;
 		$hasValue = $hasKey = FALSE;
 		$tokens = $this->tokens;
 		$n = & $this->n;
