@@ -57,7 +57,7 @@ class Configurator extends Object
 	 * @param  bool|string|array
 	 * @return self
 	 */
-	public function setDebugMode($value = TRUE)
+	public function setDebugMode($value = '')
 	{
 		$this->parameters['debugMode'] = is_string($value) || is_array($value) ? static::detectDebugMode($value) : (bool) $value;
 		$this->parameters['productionMode'] = !$this->parameters['debugMode']; // compatibility
@@ -157,7 +157,7 @@ class Configurator extends Object
 
 	/**
 	 * Returns system DI container.
-	 * @return \SystemContainer
+	 * @return \SystemContainer|DI\Container
 	 */
 	public function createContainer()
 	{
